#' Local collectivities included in so-ii
#'
#' A dataset containing the INSEE code of all local collectivities
#' (communes) included in so-ii
#'
#' @format a vector of 69 INSEE code
"so_ii_scope"

#' List of all collectivities included in so-ii
#'
#' A dataset containing the INSEE code of all local collectivities
#' included in so-ii.
#'
#' Basically this dataset is obtained as a selection from the layer
#' COMMUNE in ADMIN EXPRESS, more a renaming of variables.
#'
#' @format sf data.frame 69 rows, 7 variables
#' \describe{
#'   \item{id}{id, from IGN ADMIN EXPRESS}
#'   \item{commune}{character, official name of the commune}
#'   \item{commune_majuscule}{character, official capitalized name of the
#'         commune}
#'   \item{code}{character, INSEE code of the commune}
#'   \item{statut}{character, statut of the commune}
#'   \item{pop_yyy}{integer, official population of year yyyy in the commune}
#'   \item{epci}{character, INSEE ID of the EPCI of the commune}
#' }
#'
#' @source \url{https://www.data.gouv.fr/fr/datasets/admin-express/}
"so_ii_commune"

#' Spatial perimeter of so-ii
#'
#' A dataset containing the perimeter of so-ii.
#'
#' Basically, this dataset is obtained as
#' \code{sf::st_union(so_ii_commune)}
#'
#' @format sfc_POLYGON of length 1
"so_ii_limit"

#' CLC information for so-ii
#'
#' A dataset containing the Corine Land Cover information on so-ii.
#'
#' @format sf data.frame 1337 rows, 2 variables
#' \describe{
#'   \item{clc_2018}{character, classification from CLC 2018}
#'   \item{color}{character, default color to be used to plot so_ii_clc}
#' }
"so_ii_limit"

#' Flood frequency for the municipalities of so-ii
#'
#' A dataset containing the flood frequency by year and so-ii municipality 
#' according to the GASPAR database.
#'
#' @format matrix 78 rows, 41 variables
"so_ii_gaspar"

#' CLC information for so-ii
#'
#' A dataset containing the 2018 version of CLC information for so-ii
#'
#' @format sf object
"so_ii_clc"