#' @title Plot a thematic map of so-ii
#' 
#' @param dataset sf objectf, data to be plotted
#' @param dataset_legend list of parameters to be passed to legend
#' @param theme character, choice for the theme (if any)
#' @param bar logical, should a bar be plotted
#' @param path character, the name of the file to save the plot
#' @param gaspar_year character, the year chosen for gaspar theme
#' @param ...  some parameters that will be used by plot (from sf)
#'
#' @return Nothing useful.
#' 
#' @export
#'
#' @encoding UTF-8
#' @author Frédéric Grelot
#' 
#' @examples
#' 
#' \dontrun{
#' # To be added (soon)
#' }

map_so_ii = function(
    dataset,
    dataset_legend = NULL,
    theme = c("clc", "gaspar"),
    bar = TRUE,
    path = NULL,
    gaspar_year,
    ...
) {

    if (!is.null(path)) {
        switch(
            EXPR = tolower(tools::file_ext(path)),
            "pdf" = grDevices::pdf(path),
            "png" = grDevices::png(path),
            stop(sprintf("%s not recognized", tolower(tools::file_ext(path))))
        )
        on.exit(grDevices::dev.off())
    }

    ## Init map
    graphics::par(mai = c(.65, .60, .50, .15))
    plot(geau::so_ii_limit, axes = TRUE)

    if ("clc" %in% theme) {
        plot(
            geau::so_ii_clc[["geometry"]],
            border = NA,
            col = geau::so_ii_clc[["color"]],
            add = TRUE
        )
    }

    if ("gaspar" %in% theme) {
        border = NA
        color = NA
        if (!missing(gaspar_year)) {
            border = "grey80"
            color = ifelse(
                geau::so_ii_gaspar[ , as.character(gaspar_year)] > 0,
                scales::alpha("grey80", .5),
                NA
            )
        }

        plot(
            geau::so_ii_commune[["geometry"]],
            border = border,
            col = color,
            add = TRUE
        )
    }

    plot(dataset[["geometry"]], add = TRUE, ...)

    plot(geau::so_ii_limit, lwd = 2, add = TRUE)

    if (bar == TRUE) {
        terra::sbar(
            10, c(3.55, 43.47),
            type = "bar",
            below = "km",
            label = c(0, 5, 10),
            cex = .8
        )
    }

    if (!is.null(dataset_legend)) {
        dataset_legend = c(
            x = "bottomright",
            cex = .8,
            bg = "white",
            inset = 0.01,
            dataset_legend)
        do.call(graphics::legend, dataset_legend)
    }

    return(invisible(NULL))
}
